@@ -1,6 +1,7 @@
+@testitem "test_sciml_broadcast_interfaces" begin
 using Test
 using QuantumOptics
-using OrdinaryDiffEqCore, OrdinaryDiffEqLowOrderRK
+using OrdinaryDiffEqLowOrderRK
 
 @testset "sciml interface" begin
 
@@ -23,3 +24,4 @@ tout, ψt = semiclassical.schroedinger_dynamic([t₀, t₁], sc, fquantum, fclas
 @test sol[end] ≈ ψt[end]
 
 end
+end
\ No newline at end of file
