@@ -1,3 +1,4 @@
+@testitem "test_timeevolution_bloch_redfield.jl" begin
 using QuantumOptics
 using Test
 
@@ -42,6 +43,7 @@ tout, ρt2 = timeevolution.master_bloch_redfield([0.0:0.1:2.0;], psi0, R, H; fou
 fout2(t,rho) = expect(sz,rho)
 tout, z = timeevolution.master_bloch_redfield([0.0:0.1:2.0;], psi0, R, H; fout=fout2)
 @test length(z) == length(ρt)
-@test isa(z, Vector{ComplexF64})
+@test isa(first(z), ComplexF64)
 
 end # testset
+end
\ No newline at end of file
